@@ -8,7 +8,7 @@
  *
  *    In some countries OX, OX Open-Xchange, open xchange and OXtender
  *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the Open-Xchange, Inc. group of companies.
+ *    trademarks of the OX Software GmbH group of companies.
  *    The use of the Logos is not covered by the GNU General Public License.
  *    Instead, you are allowed to use these Logos according to the terms and
  *    conditions of the Creative Commons License, Version 2.5, Attribution,
@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2014 Open-Xchange, Inc.
+ *     Copyright (C) 2016-2020 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -109,9 +109,9 @@ public class GlobalMessageDispatcherImpl extends AbstractRealtimeJanitor impleme
     public Stanza sendSynchronously(Stanza stanza, long timeout, TimeUnit unit) throws OXException {
         String uuid = UUIDs.getUnformattedString(UUID.randomUUID());
         stanza.trace("Send synchronously. UUID: " + uuid);
-        channel.setUp(uuid, stanza);
+        ID id = channel.setUp(uuid, stanza);
         send(stanza);
-        return channel.waitFor(uuid, timeout, unit);
+        return channel.waitFor(id, timeout, unit);
     }
 
     @Override
@@ -156,7 +156,7 @@ public class GlobalMessageDispatcherImpl extends AbstractRealtimeJanitor impleme
                         ids = new HashSet<ID>();
                         targets.put(member, ids);
                     }
-                    
+
                     ids.add(id);
                 } else {
                     LOG.error("No member matches {}", routingInfo);
@@ -171,7 +171,7 @@ public class GlobalMessageDispatcherImpl extends AbstractRealtimeJanitor impleme
 
     /**
      * Filter the set of cluster {@link Member}s for a node matching the given {@link RoutingInfo}.
-     * 
+     *
      * @param routingInfo The {@link RoutingInfo} to filter the cluster {@link Member}s
      * @return null if no matching {@link Member} can be found, otherwise the first matching {@link Member}
      * @throws OXException
